==> google-displayvideo-clj-0.3.0.jar: com/adgoji/insertion_orders_assigned_targeting_options/interface.clj <==
(ns com.adgoji.insertion-orders-assigned-targeting-options.interface
  (:require
   [com.adgoji.insertion-orders-assigned-targeting-options.core
    :as insertion-orders-assigned-targeting-options.core])
  (:import
   (com.google.api.services.displayvideo.v2 DisplayVideo)))

(defn create
  [^DisplayVideo client advertiser-id insertion-order-id targeting-type assigned-targeting-option]
  (insertion-orders-assigned-targeting-options.core/create client
                                                           advertiser-id
                                                           insertion-order-id
                                                           targeting-type
                                                           assigned-targeting-option))

(defn delete
  [^DisplayVideo client advertiser-id insertion-order-id targeting-type assigned-targeting-option-id]
  (insertion-orders-assigned-targeting-options.core/delete client
                                                           advertiser-id
                                                           insertion-order-id
                                                           targeting-type
                                                           assigned-targeting-option-id))

(defn get-by-id
  [^DisplayVideo client advertiser-id insertion-order-id targeting-type assigned-targeting-option-id]
  (insertion-orders-assigned-targeting-options.core/get-by-id client
                                                              advertiser-id
                                                              insertion-order-id
                                                              targeting-type
                                                              assigned-targeting-option-id))

(defn get-list
  [^DisplayVideo client advertiser-id insertion-order-id targeting-type opts]
  (insertion-orders-assigned-targeting-options.core/get-list client
                                                             advertiser-id
                                                             insertion-order-id
                                                             targeting-type opts))

==> google-displayvideo-clj-0.5.1.jar: com/adgoji/insertion_orders_assigned_targeting_options/interface.clj <==
(ns com.adgoji.insertion-orders-assigned-targeting-options.interface
  (:require
   [com.adgoji.insertion-orders-assigned-targeting-options.core
    :as
    insertion-orders-assigned-targeting-options.core]))

(defn create
  [client advertiser-id insertion-order-id targeting-type assigned-targeting-option]
  (insertion-orders-assigned-targeting-options.core/create client
                                                           advertiser-id
                                                           insertion-order-id
                                                           targeting-type
                                                           assigned-targeting-option))

(defn delete
  [client advertiser-id insertion-order-id targeting-type assigned-targeting-option-id]
  (insertion-orders-assigned-targeting-options.core/delete client
                                                           advertiser-id
                                                           insertion-order-id
                                                           targeting-type
                                                           assigned-targeting-option-id))

(defn get-by-id
  [client advertiser-id insertion-order-id targeting-type assigned-targeting-option-id]
  (insertion-orders-assigned-targeting-options.core/get-by-id client
                                                              advertiser-id
                                                              insertion-order-id
                                                              targeting-type
                                                              assigned-targeting-option-id))

(defn get-list
  [client advertiser-id insertion-order-id targeting-type opts]
  (insertion-orders-assigned-targeting-options.core/get-list client
                                                             advertiser-id
                                                             insertion-order-id
                                                             targeting-type opts))
